Geschwindigkeit

Diese Seiten wurden speziell für die Benutzer unserer Software installiert, um sich untereinander und mit uns, Informationen, Neuigkeiten, Bilder und Dateien auszutauschen. Egal ob Dietrich's Abbundprogramm oder DC-Statik, hier sind alle Holzbau Profis richtig. Natürlich auch die ohne Holzbausoftware ;)


Wenn Sie selbst aktiv werden wollen, melden Sie sich unverbindlich mit einem Benutzernamen und einem Passwort an. Klicken Sie hierzu auf der linken Seite den Punkt "Benutzerkonto erstellen" an.


Wir wünschen unseren Besuchern einen informativen und angenehmen Aufenthalt bei Dietrich's FIX


Ihr Team Dietrich's Online - Holzbau ist unser Programm

    • Offizieller Beitrag

    Bei größeren Bauwerken habe ich immer wieder lange Wartezeiten, wenn ich bloß die aktuelle MOS oder aktuelle Ebene ändern will.
    Es scheint so, dass dafür jedes Mal die gesamten Bauwerksdateien nach allen vorhandenen MOS durchsucht werden. Erkennbare Verzögerungen gibt es schon bei Dateigrößen von 5 MB. Mein aktuelles Projekt hat inzwischen 14 MB, und da wird auch ein schneller Rechner zur Schnecke.


    Vorschlag: Alle MOS-Informationen sollen in einer eigenen Datei (oder einem anderen geeigneten Ort) gesammelt werden, damit der Zugriff schneller wird.
    Denkbar wäre z.B. die Informationen nach dem 1. Sammeln im (Cache?)-Speicher zu behalten, dann wäre nur 1 Suchvorgang pro Sitzung erforderlich.

    • Offizieller Beitrag

    Das hat nichts mit den Dateien zu tun. Beim Bearbeiten eines Projekts befinden sich alle Daten im Arbeitsspeicher. Sollte der zu klein werden, lagert das Betriebssystem natürlich in eine Auslagerungsdatei aus. Ob das bei Ihnen der Fall ist weiß ich nicht
    Mailen Sie uns das Projekt doch bitte mal durch. Dann können wir das mal untersuchen. An Extrembeispielen kann man immer am besten nach Problemen und deren Lösungen suchen.

    • Offizieller Beitrag

    Mittlerweile hat das Bauwerk fast 19 MB, allein die freie Konstruktion hat 16 MB. Das Umschalten der aktuellen Gebäude-MOS oder Ebene dauert jedesmal fast 20 sec.


    Nachdem ich das Bauwerk gespeichert, geschlossen und wieder neu aufgerufen habe, dauert das MOS-Umschalten nur noch 3 sec.


    Dann habe ich die Undo-Schritte auf Null gesetzt, und dieselbe Aktion geht ohne Verzögerung. Allein das Einschalten der Undo-Schritte erhöht die Zeit wieder auf 3 sec. Dabei spielt es zunächst keine Rolle ob 1 oder 200 Schritte eingestellt werden.


    @ Herr Neumann: Ich habe Ihnen das Projekt per PN zum Testen zugesandt.

    • Offizieller Beitrag

    Es ist klar, dass das Ausschalten der UNDO-Schritte Geschwindigkeit bringt. Wir speichern dann nicht mehr zusätzliche Daten und das spart Zeit. Die Anzahl der Schritte dürfte aber auf Dauer schon Auswirkung haben, da wir bei einer größeren Anzahl Schritte auch entsprechend mehr Daten im Speicher behalten müssen.
    Wenn ich Sie richtig verstanden habe, dann wird das Programm während des arbeitens immer langsamer. Ist das so? Auch wenn Sie ohne UNDO-Schritte arbeiten?

  • @Herr Neumann
    Bei der Gelegenheit könnten sie kurz den "Ideal-PC" für DHP beschreiben, mit dem auch größere Projekt zügig bearbeitet werden können.

    Gruss
    wutzernst

  • Hallo zusammen!
    Ich hab ja schon was geschrieben im Beta!
    Meines Erachtens nach hängt das mit den Dollarzeichen zusammen!
    Mein grosses Projekt zuckt jetzt mit allem aufgelöst astrein! Ich verlasse so ca. alle halbe Stunde das komplette Programm und danach läufts auch wieder schneller!

    Mit freundlichen Grüßen,
    Michael Bunz

    Essetre Black Forest
    Dietrich's Technology GmbH Betatester
    Software für den Holzbau, Abbund, Holzrahmenbau, Blockhausbau, Ingenieurholzbau und für die Fertighausindustrie

  • Hallo


    Kurze Frage,
    wo kann ich die Do- Undo Schritte denn einstellen???, ich hab schon gesucht aber leider nichts gefunden. !

    bis dahin
    Freundlicher Gruß


    Holzwurm

    • Offizieller Beitrag

    Die Anzahl der Do/Undo-Schritte stellt man im Modell DICAM ein (auch wenn man kein DICAM hat). Dort unter 'Datei - Einstellungen - Bildschirmelemente' (1-7-2), linke Spalte, fast ganz unten.

    Viele Grüße,
    Joachim Neumann (Dietrich's Technology GmbH)
    Software für den Holzbau, Abbund, Holzrahmenbau, Blockbau, Ingenieurholzbau und für die Fertighausindustrie

  • Hallo, ich habe auch öfter bei größeren Positionen vor allem wenn ich viele Wände belegt habe das Problem mit der Geschwindigkeit, ich denke auch dass es an der Anzahl der eingebenen Holzteile liegt. Das der Rechner nach einem Neustart des Programms schneller wird habe ich noch nicht bemerkt, werde mal darauf achten! Hier eine Verbesserung zu schaffen müsste auf jeden Fall beim nächsten Update erfolgen!
    Gruß Wutzi

    alles Paletti
    G wutzi

Jetzt mitmachen!

Sie haben noch kein Benutzerkonto auf unserer Seite? Registrieren Sie sich kostenlos und nehmen Sie an unserer Community teil!